@@ -4,14 +4,10 @@
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#include "plasma.h"
-
 #include "config-plasma.h"
 #include "packages_p.h"
-#include <KLocalizedString>
-#include <kcoreaddons_export.h>
-#include <kpackage/package.h>
-#include <kpackage/packagestructure.h>
+#include <KPackage/Package>
+#include <KPackage/PackageStructure>
 
 class PlasmoidPackage : public Plasma::GenericPackage
 {
@@ -26,19 +22,18 @@ public:
 
         package->addFileDefinition("configmodel", QStringLiteral("config/config.qml"));
         package->addFileDefinition("mainconfigxml", QStringLiteral("config/main.xml"));
+        package->setRequired("metadata", true);
     }
 
     void pathChanged(KPackage::Package *package) override
     {
         GenericPackage::pathChanged(package);
-        const KPluginMetaData md = package->metadata();
-        if (!md.isValid()) {
-            return;
-        }
-        if (md.rawData().contains(QStringLiteral("X-Plasma-ContainmentType"))) {
-            package->addFileDefinition("compactapplet", QStringLiteral("applet/CompactApplet.qml"));
-        } else {
-            package->removeDefinition("compactapplet");
+        if (const KPluginMetaData md = package->metadata(); md.isValid()) {
+            if (md.rawData().contains(QStringLiteral("X-Plasma-ContainmentType"))) {
+                package->addFileDefinition("compactapplet", QStringLiteral("applet/CompactApplet.qml"));
+            } else {
+                package->removeDefinition("compactapplet");
+            }
         }
     }
 };
